#!/bin/bash
#
# movehtml:bin/movehtml.sh
#
set -u
set -o pipefail

PROJECT_PATH="$( dirname "$( dirname "$( realpath "${BASH_SOURCE[0]}" )" )" )"
declare -r PROJECT_PATH

# shellcheck disable=SC1090 disable=SC1091
source "${PROJECT_PATH}/apis/bash-common-api/bash-common-api.sh" || exit $?
# shellcheck disable=SC1090 disable=SC1091
source "${PROJECT_PATH}/bin/movehtml-api.sh" || exit $?

function usage {
  cat <<EOF
Allow to move the file/directory pairs created by the browser when saving a complete html page.

Usage:

  $( basename "$0" ) --help
  $( basename "$0" ) [--source-dir SOURCE] [--destination-dir-base DEST] [--continue-on-error]

Options:

  -h,           --help  Display this message and exit
  -S SOURCE,    --source-dir SOURCE
                        Define source folder - default value: '$( get_default_source_folder )'
  -D DEST,      --destination-dir-base DEST
                        Define destination folder - default value: '$( get_default_destination_folder_base )'
  -C,           --continue-on-error
                        Continue on error, but default will stop if any error is encounter.
                --debug
                        More verbose
                --fix
                        Try to fix names

EOF
}

function movehtml {
  local    source_folder="$1" # R/W
  local    destination_folder_base="$2" # R/W
  local -r continue_on_error="$3"

  if [ -z "${source_folder}" ]; then
    source_folder="$( get_default_source_folder )"
  fi

  if [ -z "${source_folder}" ]; then
    echofatal 'Source folder is missing: missing in parameters and in config file.'
    return 100
  fi

  if [ -z "${destination_folder_base}" ]; then
    destination_folder_base="$( get_default_destination_folder_base )" || return $?
  fi

  if [ -z "${destination_folder_base}" ]; then
    echofatal 'Destination folder base is missing:missing in parameters and in config file.'
    return 100
  fi

  local destination_folder=
  destination_folder="$( move_html_build_destination_folder "${destination_folder_base}" )" || return $?

  echoinfo "movehtml to '${destination_folder}'"
  mkdir -p "${destination_folder}" || return $?

  move_html_all "${source_folder}" "${destination_folder}" "${continue_on_error}" || return $?
}

function main {
  local param=
  local param_continue_on_error='false'
  local param_destination_folder_base=
  local param_source_folder=

  while [ "$#" -gt 0 ] ; do
    param="$1"
    shift

    case "${param}" in
      '-h'|'--help')
        usage
        return 0
        ;;

      '-S'|'--source-dir')
        param_source_folder="$( P_param "$@" )" && shift || return $?
        ;;

      '-D'|'--destination-dir-base')
        param_destination_folder_base="$( P_param "$@" )" && shift || return $?
        ;;

      '-C'|'--continue-on-error')
        param_continue_on_error='true'
        ;;

      '--fix')
        declare -gx MOVEHTML_TRY_TO_FIX_FILENAME='true'
        ;;

      '--debug')
        declare -gx MESSAGE_API_SHOW_DEBUG='true'
        ;;

      *)
        echofatal "Unkwown option: '${param}'"
        usage >&2
        return 1
        ;;
    esac
  done

  movehtml "${param_source_folder}" "${param_destination_folder_base}" "${param_continue_on_error}" || return $?
}

main "$@" || exit $?
